@@ -34,6 +34,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
         shardcache_client_errno
         shardcache_client_errstr
         shardcache_client_tcp_timeout
+        shardcache_client_check_connection_timeout
         shardcache_client_multi_command_max_wait
         shardcache_client_use_random_node
         shardcache_client_pipeline_max
@@ -46,7 +47,7 @@ our @EXPORT = qw(
     
 );
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -133,6 +134,11 @@ sub tcp_timeout {
     return shardcache_client_tcp_timeout($self->{_client}, $new_value);
 }
 
+sub check_connection_timeout {
+    my ($self, $new_value) = @_;
+    return shardcache_client_check_connection_timeout($self->{_client}, $new_value);
+}
+
 sub multi_command_max_wait {
     my ($self, $new_value) = @_;
     return shardcache_client_multi_command_max_wait($self->{_client}, $new_value);
